@@ -13,17 +13,10 @@ Including another URLconf
     1. Import the include() function: from django.conf.urls import url, include
     2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
 """
-from django.conf.urls import url
 from django.contrib import admin
-
-try:
-    from django.urls import include
-except ImportError:
-    # Django 1.11
-    from django.conf.urls import include
-
+from django.urls import include, re_path
 
 urlpatterns = [
-    url(r"^admin/", admin.site.urls),
-    url(r"^ht/", include("health_check.urls")),
+    re_path(r"^admin/", admin.site.urls),
+    re_path(r"^ht/", include("health_check.urls")),
 ]
